km3modules.k40.HRVFIFOTimesliceFilter
=====================================

.. currentmodule:: km3modules.k40

.. autoclass:: HRVFIFOTimesliceFilter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~HRVFIFOTimesliceFilter.__init__
      ~HRVFIFOTimesliceFilter.add
      ~HRVFIFOTimesliceFilter.configure
      ~HRVFIFOTimesliceFilter.expose
      ~HRVFIFOTimesliceFilter.finish
      ~HRVFIFOTimesliceFilter.get
      ~HRVFIFOTimesliceFilter.get_skipped_frames
      ~HRVFIFOTimesliceFilter.pre_finish
      ~HRVFIFOTimesliceFilter.process
      ~HRVFIFOTimesliceFilter.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~HRVFIFOTimesliceFilter.name
   
   